summaryrefslogtreecommitdiffstats
path: root/libkscan
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:47:59 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:47:59 -0600
commitc2637a0da6d9a1c8626ca39f8451ab3b7cda487a (patch)
treebe38034f085e8be24f14f329f87a611d319e6259 /libkscan
parent3fd343f2c6b0545bd750b2939c74be3834b13274 (diff)
downloadtdegraphics-c2637a0da6d9a1c8626ca39f8451ab3b7cda487a.tar.gz
tdegraphics-c2637a0da6d9a1c8626ca39f8451ab3b7cda487a.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'libkscan')
-rw-r--r--libkscan/devselector.cpp12
-rw-r--r--libkscan/dispgamma.cpp12
-rw-r--r--libkscan/dispgamma.h2
-rw-r--r--libkscan/gammadialog.cpp2
-rw-r--r--libkscan/gammadialog.h2
-rw-r--r--libkscan/img_canvas.cpp18
-rw-r--r--libkscan/img_canvas.h4
-rw-r--r--libkscan/kscandevice.cpp30
-rw-r--r--libkscan/kscandevice.h2
-rw-r--r--libkscan/kscandoc.h2
-rw-r--r--libkscan/kscanoption.cpp2
-rw-r--r--libkscan/kscanslider.cpp6
-rw-r--r--libkscan/massscandialog.cpp2
-rw-r--r--libkscan/previewer.cpp18
-rw-r--r--libkscan/previewer.h2
-rw-r--r--libkscan/scandialog.cpp18
-rw-r--r--libkscan/scanparams.cpp18
-rw-r--r--libkscan/scanparams.h2
-rw-r--r--libkscan/scansourcedialog.cpp2
-rw-r--r--libkscan/sizeindicator.cpp8
20 files changed, 82 insertions, 82 deletions
diff --git a/libkscan/devselector.cpp b/libkscan/devselector.cpp
index 97b06e54..a8f067bb 100644
--- a/libkscan/devselector.cpp
+++ b/libkscan/devselector.cpp
@@ -22,7 +22,7 @@
#include <tqbuttongroup.h>
#include <tqcheckbox.h>
#include <tqcstring.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlabel.h>
#include <tqfile.h>
#include <tqpushbutton.h>
@@ -70,7 +70,7 @@ DeviceSelector::DeviceSelector( TQWidget *parent, TQStrList& devList,
page, "CBOX_SKIP_ON_START" );
KConfig *gcfg = KGlobal::config();
- gcfg->setGroup(TQString::tqfromLatin1(GROUP_STARTUP));
+ gcfg->setGroup(TQString::fromLatin1(GROUP_STARTUP));
bool skipDialog = gcfg->readBoolEntry( STARTUP_SKIP_ASK, false );
cbSkipDialog->setChecked( skipDialog );
@@ -81,7 +81,7 @@ DeviceSelector::DeviceSelector( TQWidget *parent, TQStrList& devList,
TQCString DeviceSelector::getDeviceFromConfig( void ) const
{
KConfig *gcfg = KGlobal::config();
- gcfg->setGroup(TQString::tqfromLatin1(GROUP_STARTUP));
+ gcfg->setGroup(TQString::fromLatin1(GROUP_STARTUP));
bool skipDialog = gcfg->readBoolEntry( STARTUP_SKIP_ASK, false );
TQCString result;
@@ -126,7 +126,7 @@ TQCString DeviceSelector::getSelectedDevice( void ) const
/* Store scanner selection settings */
KConfig *c = KGlobal::config();
- c->setGroup(TQString::tqfromLatin1(GROUP_STARTUP));
+ c->setGroup(TQString::fromLatin1(GROUP_STARTUP));
/* Write both the scan device and the skip-start-dialog flag global. */
c->writeEntry( STARTUP_SCANDEV, dev, true, true );
c->writeEntry( STARTUP_SKIP_ASK, getShouldSkip(), true, true );
@@ -141,7 +141,7 @@ void DeviceSelector::setScanSources( const TQStrList& sources,
{
bool default_ok = false;
KConfig *gcfg = KGlobal::config();
- gcfg->setGroup(TQString::tqfromLatin1(GROUP_STARTUP));
+ gcfg->setGroup(TQString::fromLatin1(GROUP_STARTUP));
TQCString defstr = gcfg->readEntry( STARTUP_SCANDEV, "" ).local8Bit();
/* Selector-Stuff*/
@@ -152,7 +152,7 @@ void DeviceSelector::setScanSources( const TQStrList& sources,
TQStringList::ConstIterator it2 = hrSources.begin();
for ( ; it.current(); ++it, ++it2 )
{
- TQString text = TQString::tqfromLatin1("&%1. %2\n%3").tqarg(1+nr).tqarg( TQString::fromLocal8Bit(*it) ).tqarg( *it2 );
+ TQString text = TQString::fromLatin1("&%1. %2\n%3").arg(1+nr).arg( TQString::fromLocal8Bit(*it) ).arg( *it2 );
TQRadioButton *rb = new TQRadioButton( text, selectBox );
selectBox->insert( rb );
diff --git a/libkscan/dispgamma.cpp b/libkscan/dispgamma.cpp
index bb10e8b5..478096e9 100644
--- a/libkscan/dispgamma.cpp
+++ b/libkscan/dispgamma.cpp
@@ -35,7 +35,7 @@ DispGamma::~DispGamma()
void DispGamma::resizeEvent (TQResizeEvent* )
{
- tqrepaint();
+ repaint();
}
void DispGamma::paintEvent( TQPaintEvent *ev )
@@ -49,11 +49,11 @@ void DispGamma::paintEvent( TQPaintEvent *ev )
p.setClipRect( ev->rect());
- p.setPen( tqcolorGroup().highlight() );
- p.setBrush( tqcolorGroup().base() );
+ p.setPen( colorGroup().highlight() );
+ p.setBrush( colorGroup().base() );
// Backgrond
p.drawRect( 0,0, w, 256 );
- p.setPen( TQPen(tqcolorGroup().midlight(), 1, DotLine));
+ p.setPen( TQPen(colorGroup().midlight(), 1, DotLine));
// horizontal Grid
for( int l = 1; l < 5; l++ )
p.drawLine( 1, l*51, 255, l*51 );
@@ -63,7 +63,7 @@ void DispGamma::paintEvent( TQPaintEvent *ev )
p.drawLine( l*51, 2, l*51, 255 );
// draw gamma-Line
- p.setPen( tqcolorGroup().highlight() );
+ p.setPen( colorGroup().highlight() );
p.moveTo( 1, vals->at(1) );
for( int i = 2; i < w-1; i++ )
{
@@ -73,7 +73,7 @@ void DispGamma::paintEvent( TQPaintEvent *ev )
}
-TQSize DispGamma::tqsizeHint( void )
+TQSize DispGamma::sizeHint( void )
{
return TQSize( 256 + 2*margin,256 + 2 * margin );
}
diff --git a/libkscan/dispgamma.h b/libkscan/dispgamma.h
index 4b8fff45..5d6bd790 100644
--- a/libkscan/dispgamma.h
+++ b/libkscan/dispgamma.h
@@ -40,7 +40,7 @@ public:
DispGamma( TQWidget *parent );
~DispGamma();
- TQSize tqsizeHint( void );
+ TQSize sizeHint( void );
TQSizePolicy sizePolicy( void );
void setValueRef( TQMemArray<SANE_Word> *newVals )
diff --git a/libkscan/gammadialog.cpp b/libkscan/gammadialog.cpp
index e1147b10..ef8a87a2 100644
--- a/libkscan/gammadialog.cpp
+++ b/libkscan/gammadialog.cpp
@@ -47,7 +47,7 @@ GammaDialog::GammaDialog( TQWidget *parent ) :
gtDisp->setValueRef( gt->getArrayPtr() );
gtDisp->resize( 280, 280 );
- connect( gt, TQT_SIGNAL(tableChanged()), gtDisp, TQT_SLOT( tqrepaint()));
+ connect( gt, TQT_SIGNAL(tableChanged()), gtDisp, TQT_SLOT( repaint()));
// setCaption( i18n( "Gamma Table" ));
diff --git a/libkscan/gammadialog.h b/libkscan/gammadialog.h
index 619e103b..b0eb016f 100644
--- a/libkscan/gammadialog.h
+++ b/libkscan/gammadialog.h
@@ -21,7 +21,7 @@
#define GAMMADIALOG_H
#include <tqwidget.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <kgammatable.h>
#include <kdialogbase.h>
diff --git a/libkscan/img_canvas.cpp b/libkscan/img_canvas.cpp
index b510f55d..b807af2f 100644
--- a/libkscan/img_canvas.cpp
+++ b/libkscan/img_canvas.cpp
@@ -226,12 +226,12 @@ void ImageCanvas::newImage( TQImage *new_image )
}
- kdDebug(29000) << "going to tqrepaint!" << endl;
- tqrepaint( true );
- kdDebug(29000) << "tqrepaint ok" << endl;
+ kdDebug(29000) << "going to repaint!" << endl;
+ repaint( true );
+ kdDebug(29000) << "repaint ok" << endl;
}
-TQSize ImageCanvas::tqsizeHint() const
+TQSize ImageCanvas::sizeHint() const
{
return( TQSize( 2, 2 ));
}
@@ -295,7 +295,7 @@ void ImageCanvas::handle_popup( int item )
default: break;
}
update_scaled_pixmap();
- tqrepaint();
+ repaint();
}
@@ -379,7 +379,7 @@ void ImageCanvas::drawContents( TQPainter * p, int clipx, int clipy, int clipw,
// p->scale( used_xscaler, used_yscaler );
// p->scale( used_xscaler, used_yscaler );
if ( x2 >= x1 && y2 >= y1 ) {
- p->tqdrawPixmap( x1, y1, *pmScaled, x1, y1 ); //, clipw, cliph);
+ p->drawPixmap( x1, y1, *pmScaled, x1, y1 ); //, clipw, cliph);
// p->setBrush( red );
// p->drawRect( x1, y1, clipw, cliph );
}
@@ -675,7 +675,7 @@ void ImageCanvas::update_scaled_pixmap( void )
if( scaleKind() == DYNAMIC )
kdDebug(28000) << "Scaling DYNAMIC" << endl;
TQSize noSBSize( visibleWidth(), visibleHeight());
- const int sbWidth = kapp->tqstyle().tqpixelMetric( TQStyle::PM_ScrollBarExtent );
+ const int sbWidth = kapp->tqstyle().pixelMetric( TQStyle::PM_ScrollBarExtent );
// if( verticalScrollBar()->visible() ) noSBSize.width()+=sbWidth;
// if( horizontalScrollBar()->visible() ) noSBSize.height()+=sbWidth;
@@ -1022,7 +1022,7 @@ const TQString ImageCanvas::imageInfoString( int w, int h, int d )
else
return TQString("-");
}
- return i18n("%1x%2 pixel, %3 bit").tqarg(w).tqarg(h).tqarg(d);
+ return i18n("%1x%2 pixel, %3 bit").arg(w).arg(h).arg(d);
}
@@ -1043,7 +1043,7 @@ const TQString ImageCanvas::scaleKindString()
return i18n("Fit Height");
break;
case ZOOM:
- return i18n("Zoom to %1 %%").tqarg( TQString::number(getScaleFactor()));
+ return i18n("Zoom to %1 %%").arg( TQString::number(getScaleFactor()));
break;
default:
return i18n("Unknown scaling!");
diff --git a/libkscan/img_canvas.h b/libkscan/img_canvas.h
index eac68e75..b1d87c76 100644
--- a/libkscan/img_canvas.h
+++ b/libkscan/img_canvas.h
@@ -121,9 +121,9 @@ public slots:
void toggleAspect( int aspect_in_mind )
{
maintain_aspect = aspect_in_mind;
- tqrepaint();
+ repaint();
}
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
void newImage( TQImage* );
void newImageHoldZoom( TQImage* );
void deleteView( TQImage *);
diff --git a/libkscan/kscandevice.h b/libkscan/kscandevice.h
index 894fa388..e5dd5100 100644
--- a/libkscan/kscandevice.h
+++ b/libkscan/kscandevice.h
@@ -438,7 +438,7 @@ private:
TQSocketNotifier *sn;
- SCANSTATUS scantqStatus;
+ SCANSTATUS scanStatus;
/* Data for the scan process */
/* This could/should go to a small help object */
diff --git a/libkscan/kscandoc.h b/libkscan/kscandoc.h
index ca57150a..14f1f2c8 100644
--- a/libkscan/kscandoc.h
+++ b/libkscan/kscandoc.h
@@ -95,7 +95,7 @@ Small dialog which enables scanning source selection, e.g. Flatbed, automatic do
- ScanParams\n
The ScanParams class is the actual core of the
- KScan Library in terms of interface tqlayout. The ScanParams class provides a ready-to-use interface for the selected scanner.\n
+ KScan Library in terms of interface layout. The ScanParams class provides a ready-to-use interface for the selected scanner.\n
\n
The scanner device is analyzed in this class and dynamically generates an interface, according to the device's properties, containing the most important operational elements. These are currently
diff --git a/libkscan/kscanoption.cpp b/libkscan/kscanoption.cpp
index 43b35d0b..f79af026 100644
--- a/libkscan/kscanoption.cpp
+++ b/libkscan/kscanoption.cpp
@@ -26,7 +26,7 @@
#include <tqcheckbox.h>
#include <tqlineedit.h>
#include <tqlabel.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqtooltip.h>
#include <tqimage.h>
#include <tqregexp.h>
diff --git a/libkscan/kscanslider.cpp b/libkscan/kscanslider.cpp
index 742a0bb6..c53d9017 100644
--- a/libkscan/kscanslider.cpp
+++ b/libkscan/kscanslider.cpp
@@ -17,7 +17,7 @@
Boston, MA 02110-1301, USA.
*/
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpushbutton.h>
#include <tqspinbox.h>
#include <tqtooltip.h>
@@ -53,7 +53,7 @@ KScanSlider::KScanSlider( TQWidget *parent, const TQString& text,
this, TQT_SLOT(slRevertValue()));
TQToolTip::add( m_stdButt,
- i18n( "Revert value back to its standard value %1" ).tqarg( stdValue ));
+ i18n( "Revert value back to its standard value %1" ).arg( stdValue ));
hb->addWidget( m_stdButt, 0 );
hb->addSpacing( 4 );
}
@@ -82,7 +82,7 @@ KScanSlider::KScanSlider( TQWidget *parent, const TQString& text,
/* set Value 0 to the widget */
slider->setValue( (int) min -1 );
- /* Add to tqlayout widget and activate */
+ /* Add to layout widget and activate */
hb->addWidget( slider, 36 );
hb->addSpacing( 4 );
hb->addWidget( m_spin, 0 );
diff --git a/libkscan/massscandialog.cpp b/libkscan/massscandialog.cpp
index 9d4a5f91..3d789b82 100644
--- a/libkscan/massscandialog.cpp
+++ b/libkscan/massscandialog.cpp
@@ -17,7 +17,7 @@
Boston, MA 02110-1301, USA.
*/
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlabel.h>
#include <tqprogressbar.h>
#include <tqgroupbox.h>
diff --git a/libkscan/previewer.cpp b/libkscan/previewer.cpp
index 0e6c8804..aca235ae 100644
--- a/libkscan/previewer.cpp
+++ b/libkscan/previewer.cpp
@@ -24,11 +24,11 @@
#include <tqtooltip.h>
#include <tqpopupmenu.h>
#include <tqfile.h>
-#include <tqtextstream.h>
+#include <textstream.h>
#include <tqcombobox.h>
#include <tqradiobutton.h>
#include <tqgroupbox.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <kdebug.h>
#include <klocale.h>
@@ -119,10 +119,10 @@ Previewer::Previewer(TQWidget *parent, const char *name )
htop->addWidget( frame );
TQVBoxLayout *top = new TQVBoxLayout( frame, KDialog::marginHint(), KDialog::spacingHint() );
- tqlayout = new TQHBoxLayout( KDialog::spacingHint() );
- top->addLayout( tqlayout, 9 );
+ layout = new TQHBoxLayout( KDialog::spacingHint() );
+ top->addLayout( layout, 9 );
TQVBoxLayout *left = new TQVBoxLayout( KDialog::spacingHint() );
- tqlayout->addLayout( left, 2 );
+ layout->addLayout( left, 2 );
/* Load autoselection values from Config file */
KConfig *cfg = KGlobal::config();
@@ -141,8 +141,8 @@ Previewer::Previewer(TQWidget *parent, const char *name )
img_canvas->setDefaultScaleKind( ImageCanvas::DYNAMIC );
img_canvas->enableContextMenu(true);
- img_canvas->tqrepaint();
- tqlayout->addWidget( img_canvas, 6 );
+ img_canvas->repaint();
+ layout->addWidget( img_canvas, 6 );
/* Actions for the previewer zoom */
KAction *act;
@@ -477,11 +477,11 @@ void Previewer::slNewDimen(TQRect r)
selectionHeightMm = (overallHeight / 1000 * r.height());
TQString s;
- s = i18n("width %1 mm").tqarg( int(selectionWidthMm));
+ s = i18n("width %1 mm").arg( int(selectionWidthMm));
emit(setScanWidth(s));
kdDebug(29000) << "Setting new Dimension " << s << endl;
- s = i18n("height %1 mm").tqarg(int(selectionHeightMm));
+ s = i18n("height %1 mm").arg(int(selectionHeightMm));
emit(setScanHeight(s));
recalcFileSize( );
diff --git a/libkscan/previewer.h b/libkscan/previewer.h
index b1400e3a..7492604b 100644
--- a/libkscan/previewer.h
+++ b/libkscan/previewer.h
@@ -89,7 +89,7 @@ private:
TQPoint calcPercent( int, int );
- TQHBoxLayout *tqlayout;
+ TQHBoxLayout *layout;
ImageCanvas *img_canvas;
TQComboBox *pre_format_combo;
TQMemArray<TQCString> format_ids;
diff --git a/libkscan/scandialog.cpp b/libkscan/scandialog.cpp
index 8d762272..2f8e73fd 100644
--- a/libkscan/scandialog.cpp
+++ b/libkscan/scandialog.cpp
@@ -19,7 +19,7 @@
*/
#include <tqlabel.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqstringlist.h>
#include <tqstrlist.h>
#include <tqtooltip.h>
@@ -55,7 +55,7 @@ ScanDialogFactory::ScanDialogFactory( TQObject *parent, const char *name )
: KScanDialogFactory( parent, name )
{
setName( "ScanDialogFactory" );
- KGlobal::locale()->insertCatalogue( TQString::tqfromLatin1("libkscan") );
+ KGlobal::locale()->insertCatalogue( TQString::fromLatin1("libkscan") );
}
KScanDialog * ScanDialogFactory::createDialog( TQWidget *parent,
@@ -113,7 +113,7 @@ void ScanDialog::createOptionsTab( void )
TQGroupBox *gb = new TQGroupBox( 1, Qt::Horizontal, i18n("Startup Options"), page, "GB_STARTUP" );
TQLabel *label = new TQLabel( i18n( "Note: changing these options will affect the scan plugin on next start." ),
gb );
- label->tqsetSizePolicy( TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed ) );
+ label->setSizePolicy( TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Fixed ) );
/* Checkbox for asking for scanner on startup */
cb_askOnStart = new TQCheckBox( i18n( "&Ask for the scan device on plugin startup"), gb );
@@ -130,7 +130,7 @@ void ScanDialog::createOptionsTab( void )
/* Read settings for startup behavior */
KConfig *gcfg = KGlobal::config();
- gcfg->setGroup(TQString::tqfromLatin1(GROUP_STARTUP));
+ gcfg->setGroup(TQString::fromLatin1(GROUP_STARTUP));
bool skipDialog = gcfg->readBoolEntry( STARTUP_SKIP_ASK, false );
bool onlyLocal = gcfg->readBoolEntry( STARTUP_ONLY_LOCAL, false );
@@ -144,7 +144,7 @@ void ScanDialog::createOptionsTab( void )
TQWidget *spaceEater = new TQWidget( page );
Q_CHECK_PTR( spaceEater );
- spaceEater->tqsetSizePolicy( TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding) );
+ spaceEater->setSizePolicy( TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding) );
}
@@ -154,7 +154,7 @@ void ScanDialog::slotNetworkToggle( bool state)
kdDebug(29000) << "slotNetworkToggle: Writing state " << writestate << endl;
KConfig *c = KGlobal::config();
- c->setGroup(TQString::tqfromLatin1(GROUP_STARTUP));
+ c->setGroup(TQString::fromLatin1(GROUP_STARTUP));
c->writeEntry( STARTUP_ONLY_LOCAL, writestate, true, true );
}
@@ -164,7 +164,7 @@ void ScanDialog::slotAskOnStartToggle(bool state)
kdDebug(29000) << "slotAskOnStartToggle: Writing state " << writestate << endl;
KConfig *c = KGlobal::config();
- c->setGroup(TQString::tqfromLatin1(GROUP_STARTUP));
+ c->setGroup(TQString::fromLatin1(GROUP_STARTUP));
c->writeEntry( STARTUP_SKIP_ASK, writestate, true, true );
}
@@ -314,7 +314,7 @@ bool ScanDialog::setup()
kfg->setGroup( GROUP_STARTUP );
/* Since this is a vertical splitter, only the width is important */
- TQString key = TQString::tqfromLatin1( SCANDIA_SPLITTER_SIZES ).tqarg( r.width());
+ TQString key = TQString::fromLatin1( SCANDIA_SPLITTER_SIZES ).arg( r.width());
kdDebug(29000) << "Read Splitter-Sizes " << key << endl;
splitter->setSizes( kfg->readIntListEntry( key ));
}
@@ -336,7 +336,7 @@ void ScanDialog::slotClose()
kfg->setGroup( GROUP_STARTUP );
/* Since this is a vertical splitter, only the width is important */
- TQString key = TQString::tqfromLatin1( SCANDIA_SPLITTER_SIZES ).tqarg( r.width());
+ TQString key = TQString::fromLatin1( SCANDIA_SPLITTER_SIZES ).arg( r.width());
kfg->writeEntry( key, splitter->sizes(), true, true);
}
}
diff --git a/libkscan/scanparams.h b/libkscan/scanparams.h
index a9f29d0e..de69b0c9 100644
--- a/libkscan/scanparams.h
+++ b/libkscan/scanparams.h
@@ -52,7 +52,7 @@ public:
ScanParams( TQWidget *parent, const char *name = 0);
~ScanParams();
#if 0
- TQSize tqsizeHint( );
+ TQSize sizeHint( );
#endif
bool connectDevice( KScanDevice* );
diff --git a/libkscan/scansourcedialog.cpp b/libkscan/scansourcedialog.cpp
index fcb3fc25..012c2e22 100644
--- a/libkscan/scansourcedialog.cpp
+++ b/libkscan/scansourcedialog.cpp
@@ -25,7 +25,7 @@
#include <tqlabel.h>
#include <tqpushbutton.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqvbox.h>
#include <tqhbox.h>
#include <tqradiobutton.h>
diff --git a/libkscan/sizeindicator.cpp b/libkscan/sizeindicator.cpp
index 582f2330..e0884e08 100644
--- a/libkscan/sizeindicator.cpp
+++ b/libkscan/sizeindicator.cpp
@@ -19,7 +19,7 @@
#include "sizeindicator.h"
-#include <tqpalette.h>
+#include <palette.h>
#include <tqimage.h>
#include <kimageeffect.h>
@@ -34,7 +34,7 @@ SizeIndicator::SizeIndicator( TQWidget *parent, long thres, long crit )
{
sizeInByte = -1;
setFrameStyle( TQFrame::Box | TQFrame::Sunken );
- setMinimumWidth( fontMetrics().width( TQString::tqfromLatin1("MMM.MM MB") ));
+ setMinimumWidth( fontMetrics().width( TQString::fromLatin1("MMM.MM MB") ));
setCritical( crit );
threshold = thres;
@@ -79,7 +79,7 @@ void SizeIndicator::setSizeInByte( long newSize )
fwidth = 2;
}
- t = unit.tqarg( sizer, fwidth, 'f', precision);
+ t = unit.arg( sizer, fwidth, 'f', precision);
setText(t);
}
@@ -100,7 +100,7 @@ void SizeIndicator::drawContents( TQPainter *p )
warnColor.setHsv( 0, c, c );
p->drawImage( 0,0,
- KImageEffect::unbalancedGradient( s, tqcolorGroup().background(),
+ KImageEffect::unbalancedGradient( s, colorGroup().background(),
warnColor, KImageEffect::CrossDiagonalGradient, 200,200 ));
}
/* Displaying the text */
diff --git a/libkscan/kscandevice.cpp b/libkscan/kscandevice.cpp
index a00abd4b..acd8f92e 100644
--- a/libkscan/kscandevice.cpp
+++ b/libkscan/kscandevice.cpp
@@ -26,7 +26,7 @@
#include <tqcheckbox.h>
#include <tqlineedit.h>
#include <tqlabel.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqtooltip.h>
#include <tqimage.h>
#include <tqfileinfo.h>
@@ -175,7 +175,7 @@ KScanDevice::KScanDevice( TQObject *parent )
gui_elements.setAutoDelete( true );
scanner_initialised = false; /* stays false until openDevice. */
- scantqStatus = SSTAT_SILENT;
+ scanStatus = SSTAT_SILENT;
data = 0; /* temporary image data buffer while scanning */
sn = 0; /* socket notifier for async scanning */
@@ -282,7 +282,7 @@ void KScanDevice::slCloseDevice( )
scanner_name = UNDEF_SCANNERNAME;
if( scanner_handle )
{
- if( scantqStatus != SSTAT_SILENT )
+ if( scanStatus != SSTAT_SILENT )
{
kdDebug(29000) << "Scanner is still active, calling cancel !" << endl;
sane_cancel( scanner_handle );
@@ -659,11 +659,11 @@ void KScanDevice::slReloadAll( )
void KScanDevice::slStopScanning( void )
{
kdDebug(29000) << "Attempt to stop scanning" << endl;
- if( scantqStatus == SSTAT_IN_PROGRESS )
+ if( scanStatus == SSTAT_IN_PROGRESS )
{
emit( sigScanFinished( KSCAN_CANCELLED ));
}
- scantqStatus = SSTAT_STOP_NOW;
+ scanStatus = SSTAT_STOP_NOW;
}
@@ -673,7 +673,7 @@ const TQString KScanDevice::previewFile()
if( !dir.endsWith("/") )
dir += "/";
- TQString fname = dir + TQString::tqfromLatin1(".previews/");
+ TQString fname = dir + TQString::fromLatin1(".previews/");
TQString sname( getScannerName(shortScannerName()) );
sname.replace( '/', "_");
@@ -1090,7 +1090,7 @@ KScanStat KScanDevice::acquire_data( bool isPreview )
if( stat == KSCAN_OK )
{
overall_bytes = 0;
- scantqStatus = SSTAT_IN_PROGRESS;
+ scanStatus = SSTAT_IN_PROGRESS;
pixel_x = 0;
pixel_y = 0;
overall_bytes = 0;
@@ -1115,7 +1115,7 @@ KScanStat KScanDevice::acquire_data( bool isPreview )
do
{
doProcessABlock();
- if( scantqStatus != SSTAT_SILENT )
+ if( scanStatus != SSTAT_SILENT )
{
sane_stat = sane_get_parameters( scanner_handle, &sane_scan_param );
kdDebug(29000) << "--ProcessABlock-Loop" << endl;
@@ -1126,7 +1126,7 @@ KScanStat KScanDevice::acquire_data( bool isPreview )
kdDebug(29000) << "pixels_per_line : " << sane_scan_param.pixels_per_line << endl;
kdDebug(29000) << "bytes_per_line : " << sane_scan_param.bytes_per_line << endl;
}
- } while ( scantqStatus != SSTAT_SILENT );
+ } while ( scanStatus != SSTAT_SILENT );
}
}
@@ -1410,9 +1410,9 @@ void KScanDevice::doProcessABlock( void )
}
}
- if( goOn && scantqStatus == SSTAT_STOP_NOW )
+ if( goOn && scanStatus == SSTAT_STOP_NOW )
{
/* scantqStatus is set to SSTAT_STOP_NOW due to hitting slStopScanning */
/* Mostly that one is fired by the STOP-Button in the progress dialog. */
/* This is also hit after the normal finish of the scan. Most probably,
@@ -1421,7 +1421,7 @@ void KScanDevice::doProcessABlock( void )
*/
kdDebug(29000) << "Stopping the scan progress !" << endl;
goOn = false;
- scantqStatus = SSTAT_SILENT;
+ scanStatus = SSTAT_SILENT;
emit( sigScanFinished( KSCAN_OK ));
}
@@ -1435,13 +1435,13 @@ void KScanDevice::doProcessABlock( void )
{
/** Everythings okay, the picture is ready **/
kdDebug(29000) << "last frame reached - scan successful" << endl;
- scantqStatus = SSTAT_SILENT;
+ scanStatus = SSTAT_SILENT;
emit( sigScanFinished( KSCAN_OK ));
}
else
{
/** EOF und nicht letzter Frame -> Parameter neu belegen und neu starten **/
- scantqStatus = SSTAT_NEXT_FRAME;
+ scanStatus = SSTAT_NEXT_FRAME;
kdDebug(29000) << "EOF, but another frame to scan" << endl;
}
@@ -1449,7 +1449,7 @@ void KScanDevice::doProcessABlock( void )
if( sane_stat == SANE_STATUS_CANCELLED )
{
- scantqStatus = SSTAT_STOP_NOW;
+ scanStatus = SSTAT_STOP_NOW;
kdDebug(29000) << "Scan was cancelled" << endl;
// stat = KSCAN_CANCELLED;
@@ -1410,9 +1410,9 @@ void KScanDevice::doProcessABlock( void )
{
- /* scantqStatus is set to SSTAT_STOP_NOW due to hitting slStopScanning */
+ /* scanStatus is set to SSTAT_STOP_NOW due to hitting slStopScanning */
/* Mostly that one is fired by the STOP-Button in the progress dialog. */
/* This is also hit after the normal finish of the scan. Most probably,
diff --git a/libkscan/scanparams.cpp b/libkscan/scanparams.cpp
index ec9e77fe..25ef9879 100644
--- a/libkscan/scanparams.cpp
+++ b/libkscan/scanparams.cpp
@@ -27,7 +27,7 @@
#include <tqimage.h>
#include <tqtooltip.h>
#include <tqmessagebox.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqdict.h>
#include <tqprogressdialog.h>
#include <tqscrollview.h>
@@ -111,7 +111,7 @@ bool ScanParams::connectDevice( KScanDevice *newScanDevice )
/* initialise own widgets */
cb_gray_preview = 0;
/* A top tqlayout box */
// TQVBoxLayout *top = new TQVBoxLayout(this, 6);
TQHBox *hb = new TQHBox( this );
hb->setSpacing( KDialog::spacingHint() );
@@ -120,7 +120,7 @@ bool ScanParams::connectDevice( KScanDevice *newScanDevice )
(void ) new TQLabel( cap, hb );
m_led = new KLed( hb );
m_led->setState( KLed::Off );
- m_led->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ));
+ m_led->setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ));
(void) new KSeparator( KSeparator::HLine, this);
@@ -160,7 +160,7 @@ bool ScanParams::connectDevice( KScanDevice *newScanDevice )
connect( pb, TQT_SIGNAL(clicked()), this, TQT_SLOT(slStartScan()) );
pb = kbb->addButton( i18n( "&Preview Scan" ));
connect( pb, TQT_SIGNAL(clicked()), this, TQT_SLOT(slAcquirePreview()) );
- kbb->tqlayout();
+ kbb->layout();
/* Initialise the progress dialog */
progressDialog = new TQProgressDialog( i18n("Scanning in progress"),
@@ -501,9 +501,9 @@ TQScrollView *ScanParams::scannerParams( )
}
TQWidget *spacer = new TQWidget( pbox );
- spacer->tqsetSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Expanding);
+ spacer->setSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Expanding);
- pbox->setMinimumWidth( pbox->tqsizeHint().width() );
+ pbox->setMinimumWidth( pbox->sizeHint().width() );
sv->setMinimumWidth( pbox->minimumWidth() );
sv->addChild( pbox );
@@ -591,7 +591,7 @@ void ScanParams::slFileSelect( void )
fi_item = filterList.next() )
{
- filter.append( TQString::tqfromLatin1( prefix + fi_item.lower()) );
+ filter.append( TQString::fromLatin1( prefix + fi_item.lower()) );
}
}
else
@@ -638,7 +638,7 @@ void ScanParams::slVirtScanModeSelect( int id )
kdDebug(29000) << "Found File in Filename-Option: " << vf << endl;
TQFileInfo fi( vf );
- if( fi.extension() != TQString::tqfromLatin1("pnm") )
+ if( fi.extension() != TQString::fromLatin1("pnm") )
virt_filename->set(TQCString(""));
}
} else {
@@ -695,7 +695,7 @@ void ScanParams::virtualScannerParams( void )
TQHBoxLayout *hb = new TQHBoxLayout();
top->addLayout( hb );
w = virt_filename->widget();
- w->setMinimumHeight( (w->tqsizeHint()).height());
+ w->setMinimumHeight( (w->sizeHint()).height());
connect( w, TQT_SIGNAL(returnPressed()), this,
TQT_SLOT( slCheckGlob()));
@@ -111,7 +111,7 @@ bool ScanParams::connectDevice( KScanDevice *newScanDevice )
/* initialise own widgets */
cb_gray_preview = 0;
- /* A top tqlayout box */
+ /* A top layout box */
// TQVBoxLayout *top = new TQVBoxLayout(this, 6);
TQHBox *hb = new TQHBox( this );